from typing import Final

from volworld_aws_api_common.api.AA import AA

from volworld_aws_api_common.test.aws.url import build_api_root_url
from volworld_aws_api_common.test.aws.url import build_url
from volworld_aws_api_common.test.aws.url import build_dynamic_url

# ROOT__: Final[str] = build_api_root_url(AA.Auth)
#
# doSignupUrl: Final[str] = build_url(ROOT__, AA.Signup)
#
# doLoginUrl: Final[str] = build_url(ROOT__, AA.Login)
#
# # doLogoutUrl: Final[str] = build_url(ROOT__, AA.Logout)
#
# currentUserUrl: Final[str] = build_url(ROOT__, AA.UserId)


ROOT__: Final[list] = [AA.Auth]

def do_signup_url():
    return build_dynamic_url(ROOT__, [AA.Signup])

def do_login_url():
    return build_dynamic_url(ROOT__, [AA.Login])

def current_user_url():
    return build_dynamic_url(ROOT__, [AA.UserId])



from behave import *
import time
from volworld_common.test.behave.BehaveUtil import BehaveUtil


def waiting_for_animation():
    time.sleep(0.5)


@when('waiting animation')
def when__waiting_animation(c):
    time.sleep(0.5)


@when('waiting animation for {sec} sec')
def when__waiting_animation_for_sec(c, sec: str):
    time.sleep(BehaveUtil.clear_float(sec))


@when('sleep for {sec} sec')
def when__sleep(c, sec: str):
    time.sleep(BehaveUtil.clear_float(sec))


@when('waiting server update for {sec} sec')
def when__waiting_server_update(c, sec: str):
    time.sleep(BehaveUtil.clear_float(sec))